<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\AdminGiftRequest;
use App\Models\Gift;
use App\Repositories\GiftRepository;
use Illuminate\Support\Facades\Storage;

class GiftController extends Controller
{
    public function index()
    {
        $gifts = GiftRepository::query()->paginate(20);

        return view('admin.gift.index', compact('gifts'));
    }

    public function create()
    {
        return view('admin.gift.create');
    }

    public function store(AdminGiftRequest $request)
    {
        GiftRepository::storeByRequest($request);

        return to_route('admin.gift.index')->withSuccess(__('Gift created successfully'));
    }

    public function edit(Gift $gift)
    {
        return view('admin.gift.edit', compact('gift'));
    }

    public function update(AdminGiftRequest $request, Gift $gift)
    {
        GiftRepository::updateByRequest($request, $gift);

        return to_route('admin.gift.index')->withSuccess(__('Gift updated successfully'));
    }

    public function destroy(Gift $gift)
    {
        if ($gift->orders()->exists() || $gift->carts()->exists()) {
            return to_route('admin.gift.index')->withError(__('Gift cannot be deleted! Because it has orders or carts'));
        }

        $media = $gift->media;

        $gift->delete();

        if ($media && Storage::exists($media->src)) {
            Storage::delete($media->src);
            $media->delete();
        }

        return to_route('admin.gift.index')->withSuccess(__('Gift deleted successfully'));
    }

    public function statusToggle(Gift $gift)
    {
        $gift->update(['is_active' => ! $gift->is_active]);

        return to_route('admin.gift.index')->withSuccess(__('Status updated successfully'));
    }
}
